import React from 'react';

import HeadView from '../view/HeadView';
import TableBtnView from '../view/TableBtnView';
import CommonSearchForm from '../view/CommonSearchForm';
import { Input, Button, DatePicker, Divider, Modal, message } from 'antd'
import moment from 'moment'
import Fetch from '../fetch';
import TableView from '../view/TableView';
const confirm = Modal.confirm;
export default class KeyWord extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      data: [],
      loading: false,
      visible: false,
      savedate: {},
      formData: {
        __key: Date.now(),
        keywords: '',
      },
      resetKey: Date.now(),
      closeKey: Date.now()
    };
  }

  componentDidMount() {
    document.title = '关键词维护';
    this.getData();
  }

  setFormData = data => {
    console.log('form', data);
    this.setState({
      formData: data,
    });
  }

  searchonClick = data => {
    console.log('form', data);
    this.setState({
      formData: data,
    });
    this.setState({ loading: true })
    Fetch.searchLaw({ ...data })
      .then(res => {
        for (var i = 0; i < res.length; i++) {
          res[i]['index'] = i + 1;
        }
        this.setState({
          data: res,
          loading: false
        });
      });
  }
  getData = () => {
    const { formdata } = this.state;
    this.setState({ loading: true })
    Fetch.searchLaw({ formdata })
      .then(res => {
        console.log(res)
        this.setState({
          data: res,
          loading: false
        });
      });
  }
  onInputChange = ({ target: { value, name } }) => {
    this.setState(({ formdata }) => ({
      formdata: {
        ...formdata,
        [name]: value
      }
    }))
  }
  saveInputChange = ({ target: { value, name } }) => {
    this.setState(({ savedate }) => ({
      savedate: {
        ...savedate,
        [name]: value
      }
    }))
  }
  Seaech = () => {
    const { formdata } = this.state;
    Fetch.searchLaw(formdata)
      .then(res => {
        for (var i = 0; i < res.length; i++) {
          res[i]['index'] = i + 1;
        }
        this.setState({
          data: res
        });
      });
  }
  Reset = () => {
    this.setState({
      resetKey: Date.now(),
      formdata: {}
    }, this.getData);
  }

  showModal = (id) => {
  console.log(id)
    this.setState({
      visible: true,
    });
    Fetch.searchLawFind(id)
      .then(res => {
        console.log(res)
        this.setState({ savedate: res })
      })
  }

  handleOk = () => {
    this.setState({ loading: true });
    const { savedate } = this.state;
    console.log(savedate)
    if (!savedate.keywords) {
      return message.warning("关键词不能为空");
    }
    Fetch.searchLawSave(savedate)
      .then(res => {
        console.log(res)
        if (res.code === 0) {
          this.setState({
            loading: false,
            visible: false,
            closeKey: Date.now()
          }, this.getData);
          message.success("提交成功！")
        } else {
          message.error('保存失败，请联系管理员', 2)
        }
      });
  }

  handleCancel = () => {
    this.setState({
      closeKey: Date.now(),
      visible: false
    });
  }

  deleteItems = (id) => {
    confirm({
      title: '确认要删除这条数据吗?',
      onOk: () => {
        Fetch.searchLawDelete(id)
          .then(data => {
              message.success("删除成功！")
              this.setState({
                resetKey: Date.now(),
                formdata: {}
              }, this.getData);
          })
      }
    });
  }
  render() {
    const columns = [{
      title: '编号',
      dataIndex: 'id',
      key: 'id'
    }, {
      title: '关键词',
      dataIndex: 'keywords',
      key: 'keywords'
    }, {
      title: '创建时间',
      dataIndex: 'createTime',
      key: 'createTime',
      render: text => <span>{moment(text).format("YYYY-MM-DD HH:mm")}</span>
    }, {
      title: '操作',
      key: 'action',
      render: (text, record) => (
        <span>
          <label onClick={() => this.showModal(record.id)} className='theme-color' style={{ cursor: 'pointer' }}>编辑</label>
          <Divider type="vertical" />
          <label onClick={() => this.deleteItems(record.id)} className='theme-color' style={{ cursor: 'pointer' }}>删除</label>
        </span>
      ),
    }];
    const { data, resetKey, visible, loading, savedate, closeKey, formData } = this.state;
    console.log(savedate)
    return (

      <div className="app-page">
        <HeadView history={this.props.history} />
        <div style={{ marginLeft: '90%', marginBottom: '20px', marginTop: '20px' }}>
          <Button type="primary" size='large' onClick={() => this.showModal('new')}>新增</Button>
        </div>
        <div style={{ background: '#fff', margin: 20 }}>
          <CommonSearchForm
            {...this.props}
            formData={formData}
            setFormData={this.setFormData}
            searchonClick={this.searchonClick}
            pathName={this.props.location.pathname}
            data={[
              {
                type: 'input', name: '关键词', label: '关键词', key: 'keywords'
              }
            ]} />
          <TableView columns={columns} data={data} pageSize='10' size='default' loading={loading} />
        </div>
        <Modal
          key={closeKey}
          confirmLoading={loading}
          visible={visible}
          title="新增关键词"
          onOk={this.handleOk}
          onCancel={this.handleCancel}
          bodyStyle={{ lineHeight: 4 }}
        >
          <Input addonBefore="关键词" name='keywords' onChange={this.saveInputChange} value={savedate.keywords || ''} />
        </Modal>
      </div>
    );
  }

}
